"""General template for the operations manger report"""
import datetime
from string import Template
from typing import Dict, List

from ws_metrics.reporting.interfaces import RTemplate
from ws_metrics.schema import AbstractTextFile


class OperationsReportTemplate(RTemplate):
    """A Report specific to Operations"""

    def __init__(self):
        self.file_type = ".csv"

    def template(self) -> Template:
        """
        Define template for this report

        :return: Report Template
        """
        return Template("$result_string")

    def render_template(self, title: str, data: Dict) -> AbstractTextFile:
        """
        render template to file

        :param title: filename
        :param data: data to render
        :return: an AbstractTextFile
        """
        result_string = ""

        for result in data["results"]:
            result_string += self.format_result(result)

        content = Template.substitute(self.template(), {"result_string": result_string})

        return AbstractTextFile(title, content)

    @staticmethod
    def format_result(data: List) -> str:
        """
        Format the sql results for template rendering

        :param data: the result to format
        :return: string representation of the data
        """
        for element in data:
            if isinstance(element, datetime.datetime):
                element.strftime("%Y-%m-%dT%H:%M:%S")

        line = ",".join(map(str, data))

        return line + "\n"
